@@ -272,17 +272,23 @@ class IgnoreBugs < Array
     @@path_mutex[path] = Mutex.new if @@path_mutex[path] == nil
 
     if FileTest.exist?(path)
-      open(path).each { |bug|
-        if /\s*#/ =~ bug
-	  next
-        end
-        if /\s*(\S+)/ =~ bug
-	  self << $1
-        end
-      }
+      begin
+        open(path).each { |bug|
+          if /\s*#/ =~ bug
+            next
+          end
+          if /\s*(\S+)/ =~ bug
+            self << $1
+          end
+        }
+      rescue Errno::EACCES
+        # read-access is not possible, warn the user that the
+        # file won't be taken into account
+        $stderr.puts sprintf(_("W: Cannot read from %s"), @path)
+      end
     end
 
-    @gavewarning = nil
+    @gavewritewarning = nil
   end
 
   def add(entry, write=true)
@@ -293,10 +299,11 @@ class IgnoreBugs < Array
             file.puts entry
           }
         rescue Errno::EACCES
-          # write-access is not possible, ignore it for now.
-          if @gavewarning.nil?
-            $stderr.puts _("W: Cannot write to bug ignore list file")
-            @gavewarning = true
+          # write-access is not possible, warn the user that the
+          # file won't be updated
+          if @gavewritewarning.nil?
+            $stderr.puts sprintf(_("W: Cannot write to %s"), @path)
+            @gavewritewarning = true
           end
         end
       }
@@ -371,7 +378,7 @@ class Viewer
 	  return false
 	when /^#?(\d+)$/
 	  if @config.querybts != nil
-	    system("#{@config.querybts} #{$1} < /dev/tty")
+	    system("#{@config.querybts} -u text #{$1} < /dev/tty")
           else
             @config.frontend.puts sprintf(_("You must install the reportbug package to be able to do this"))
           end
@@ -476,7 +483,7 @@ class Viewer
 	  pin_ver = cur_pkgs[pkg]['version']
         else
           pin_ver = "*"
-          pin_pri = "-40"
+          pin_pri = "-30000"
 	end
 	holdstr << "
 Explanation: Pinned by apt-listbugs at #{Time.now}"
@@ -811,12 +818,12 @@ module Factory
       bugs.delete_if { |bug| !config.fbugs.include?(bug.bug_number)}
     end
 
-    def iterate_fixed_found_version(space_delimited_bts_version, pkg_name)
+    def iterate_fixed_found_version(bts_versions, pkg_name)
       # iterate relevant versions, used to parsing Fixed and Found tags of BTS
-      if space_delimited_bts_version.nil?
+      if bts_versions.nil?
         return;
       end
-      space_delimited_bts_version.split(" ").each { |version|
+      bts_versions.split(" ").each { |version|
         # check each fixed_version
         case version
         when /^(.*)\/(.*)$/
@@ -833,13 +840,13 @@ module Factory
       }
     end
 
-    def find_max_version_below_ver(space_delimited_bts_version, new_ver, pkg_name)
-      # find the max version from found/fixed that is below new_ver
-      # data format of space_delimited_bts_version:
-      # space-delimited PACKAGE/VERSION, or VERSION.
+    def find_max_version_below_ver(bts_versions, new_ver, pkg_name)
+      # find the max version from found/fixed that is below or equal to new_ver
+      # data format of bts_versions:
+      # space-delimited sequence of PACKAGE/VERSION or VERSION items.
 
       maxver=nil
-      iterate_fixed_found_version(space_delimited_bts_version, pkg_name) { |each_ver|
+      iterate_fixed_found_version(bts_versions, pkg_name) { |each_ver|
         # check each fixed_ver
         if Debian::Dpkg.compare_versions(each_ver, "le", new_ver) &&
             ( maxver == nil || Debian::Dpkg.compare_versions(maxver, "le", each_ver) )
@@ -849,15 +856,15 @@ module Factory
       maxver
     end
 
-    def find_min_version_above_ver(space_delimited_bts_version, new_ver, pkg_name)
-      # find the min version from found/fixed that is above new_ver
-      # data format of space_delimited_bts_version:
-      # space-delimited PACKAGE/VERSION, or VERSION.
+    def find_min_version_above_ver(bts_versions, new_ver, pkg_name)
+      # find the min version from found/fixed that is strictly above new_ver
+      # data format of bts_versions:
+      # space-delimited sequence of PACKAGE/VERSION or VERSION items.
 
       minver=nil
-      iterate_fixed_found_version(space_delimited_bts_version, pkg_name) { |each_ver|
+      iterate_fixed_found_version(bts_versions, pkg_name) { |each_ver|
         # check each each_ver
-        if Debian::Dpkg.compare_versions(each_ver, "ge", new_ver) &&
+        if Debian::Dpkg.compare_versions(each_ver, "gt", new_ver) &&
             ( minver == nil || Debian::Dpkg.compare_versions(minver, "ge", each_ver) )
           minver = each_ver
         end
@@ -866,8 +873,8 @@ module Factory
     end
 
     def am_i_buggy(ver, fixed, found)
-      # find out if this version is buggy or not depending on the fixed / found array.
-      # how do I handle casees of found / fixed = nil?
+      # find out if this version is buggy or not depending on the
+      # fixed / found arrays.
 
       puts " .. checking ver #{ver} against fixed:#{fixed} found:#{found}" if $DEBUG
 
@@ -885,40 +892,44 @@ module Factory
 
       val=true
 
-      # if ( found_max_below <= fixed_max_below ), I know it's fixed by ver.
-      # there are cases where found_max_below and fixed_max_below isn't available, ingnore it.
-
       if fixed_max_below == nil && found_max_below == nil
-        # this is a hard thing to handle, but do some guessing here:
-        # bug was not fixed or found before this version in consideration.
-        # It either means it wasn't found before this version, or 'found' version info is missing from BTS.
+        # this is a hard thing to handle, but do some guessing here...
+        # the bug was not fixed or found before this version:
+        # it either means it wasn't found before this version,
+        # or 'found' version info is missing from BTS
         if found_min_above == nil
-          # no new version found; which I guess signifies that the BTS is missing version info.
-          puts " ... found is nil; I guess I am buggy" if $DEBUG
+          # no new version found;
+          # which I guess means that the BTS is missing version info
+          puts " ... no found info: I guess I am buggy" if $DEBUG
           val=true
         else
-          # found_min_above is not nil, which means I may not be
-          # buggy; except for a case where it's fixed before the
-          # found_min, which probably means 'found' info is missing
-          # from BTS.
+          # found_min_above is not nil, which means I may not be buggy;
+          # except for a case where it's fixed before the found_min,
+          # which probably means 'found' info is missing from BTS
           if fixed_min_above == nil ||
               Debian::Dpkg.compare_versions(fixed_min_above, "gt", found_min_above)
-            puts " ... Bug is 'found' on a later version, I guess I am not buggy" if $DEBUG
+            puts " ... bug found in a later version: I guess I am not buggy" if $DEBUG
             val=false
           else
-            puts " ... Bug is 'fixed' on a later version before it's found again, I guess I am buggy" if $DEBUG
+            puts " ... bug fixed in a later version before it's found again: I guess I am buggy" if $DEBUG
             val=true
           end
         end
       else if fixed_max_below == nil
-             puts " ... found in prior version but not yet fixed" if $DEBUG
+             # the bug was found before (or in) this version, but fixed
+             # later (or never): it means I am buggy
+             puts " ... bug found in a prior version, but not yet fixed: I am buggy" if $DEBUG
              val=true
            else if found_max_below == nil || Debian::Dpkg.compare_versions(fixed_max_below, "gt", found_max_below)
-                  # this bugreport has recently been fixed
-                  puts " ... this bugreport is not found in this version or fixed_max_below > found_max_below: assuming that this bug does not apply for this version" if $DEBUG
+                  # the bug was not found between the latest fixed version
+                  # and this version: it means I am not buggy
+                  puts " ... bug not found between the latest fixed version and this version: I am not buggy" if $DEBUG
                   val=false
                 else
-                  # default path.
+                  # the bug was indeed found between the latest fixed version
+                  # and this version: it means I am buggy
+                  puts " ... bug found between the latest fixed version and this version: I am buggy" if $DEBUG
+                  val=true
                 end
            end
       end
